pub struct QueryParamTokenExtractor {
pub key: String,
}Expand description
Searches the auth token in the query parameters, eg. returns <token> when looking at a request with URL https://<url>/<path>?token=<token>.
The key to be searched for is configurable. Default is: “token”.
SECURITY: This extractor should be used with caution! Only use it if you are informed about the security implication of providing tokens through query parameters.
Fields
key: StringImplementations
Sourceimpl QueryParamTokenExtractor
impl QueryParamTokenExtractor
pub fn extracting_key(key: impl Into<String>) -> Self